"use strict";
Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "prettyFormatter", {
  enumerable: true,
  get: function() {
    return prettyFormatter;
  }
});
const _interop_require_default = require("@swc/helpers/_/_interop_require_default");
const _webpack = require("webpack");
const _chalk = /* @__PURE__ */ _interop_require_default._(require("@modern-js/utils/chalk"));
const formatTraceEntry = (entry) => {
  const { callee, file, line, column } = entry;
  const prompt = _chalk.default.gray("at");
  let location = "<anonymous>";
  file && (location = file);
  line && (location += `:${line}`);
  column && (location += `:${column}`);
  const sign = `${callee} (${location})`;
  return `    ${prompt} ${sign}`;
};
const SIGN_TEXT = {
  error: " ERROR ",
  warning: " WARN ",
  cause: " CAUSE "
};
const SIGN_COLOR = {
  error: _chalk.default.bgRed.bold.black,
  warning: _chalk.default.bgYellow.bold.black
};
const prettyFormatter = (e) => {
  const leadings = [];
  {
    const text = SIGN_TEXT[e.parent ? "cause" : e.type];
    const sign = SIGN_COLOR[e.type](text);
    leadings.push(sign, " ");
  }
  {
    const colorize = e.type === "error" ? _chalk.default.red.bold : _chalk.default.yellow.bold;
    const name = colorize(e.name);
    leadings.push(name, _chalk.default.gray(": "), e.message);
  }
  const ret = [
    leadings.join("")
  ];
  if (e.raw instanceof _webpack.WebpackError) {
    typeof e.raw.details === "string" && ret.push(e.raw.details);
  }
  ret.push(...e.trace.map(formatTraceEntry));
  e.cause && ret.push(prettyFormatter(e.cause));
  return ret.join("\n");
};
