"use strict";
Object.defineProperty(exports, "__esModule", {
  value: true
});
function _export(target, all) {
  for (var name in all)
    Object.defineProperty(target, name, {
      enumerable: true,
      get: all[name]
    });
}
_export(exports, {
  compareTraces: function() {
    return compareTraces;
  },
  compareTraceFragments: function() {
    return compareTraceFragments;
  },
  mergeTraceHeads: function() {
    return mergeTraceHeads;
  },
  flattenCausesTransformer: function() {
    return flattenCausesTransformer;
  }
});
const _interop_require_default = require("@swc/helpers/_/_interop_require_default");
const _lodash = /* @__PURE__ */ _interop_require_default._(require("@modern-js/utils/lodash"));
const compareTraces = (trace1, trace2) => {
  if (trace1.length !== trace2.length) {
    return false;
  }
  for (let i = 0; i < trace1.length; i++) {
    const s1 = trace1[i];
    const s2 = trace2[i];
    if (s1.file !== s2.file || s1.line !== s2.line || s1.column !== s2.column) {
      return false;
    }
  }
  return true;
};
const compareTraceFragments = (trace1, trace2) => {
  const len = Math.min(trace1.length, trace2.length);
  return compareTraces(trace1.length === len ? trace1 : trace1.slice(0, len), trace2.length === len ? trace2 : trace2.slice(0, len));
};
const mergeTraceHeads = (traces) => {
  const heads = [];
  const tails = [];
  for (const [head, ...rest] of traces) {
    if (!heads.length) {
      heads.push(head);
      tails.push(...rest);
    } else if (compareTraceFragments(tails, rest)) {
      heads.push(head);
    } else {
      return null;
    }
  }
  return [
    ...heads,
    ...tails
  ];
};
const flattenCausesTransformer = (e) => {
  const traces = [
    e.trace,
    ..._lodash.default.map(e.causes, "trace")
  ];
  const merged = mergeTraceHeads(traces);
  if (merged) {
    e.trace = merged;
    e.causes = [];
  }
  return e;
};
